@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
@@ -14,6 +14,7 @@ import itertools
 import os
 import sys
 import tempfile
+import threading
 import zlib
 
 from lib.core.compat import xrange
@@ -65,6 +66,8 @@ class BigArray(list):
     >>> _ = _ + [1]
     >>> _[-1]
     1
+    >>> len([_ for _ in BigArray(xrange(100000))])
+    100000
     """
 
     def __init__(self, items=None):
@@ -72,6 +75,7 @@ class BigArray(list):
         self.chunk_length = sys.maxsize
         self.cache = None
         self.filenames = set()
+        self._lock = threading.Lock()
         self._os_remove = os.remove
         self._size_counter = 0
 
@@ -93,18 +97,19 @@ class BigArray(list):
         return self
 
     def append(self, value):
-        self.chunks[-1].append(value)
+        with self._lock:
+            self.chunks[-1].append(value)
 
-        if self.chunk_length == sys.maxsize:
-            self._size_counter += _size_of(value)
-            if self._size_counter >= BIGARRAY_CHUNK_SIZE:
-                self.chunk_length = len(self.chunks[-1])
-                self._size_counter = None
+            if self.chunk_length == sys.maxsize:
+                self._size_counter += _size_of(value)
+                if self._size_counter >= BIGARRAY_CHUNK_SIZE:
+                    self.chunk_length = len(self.chunks[-1])
+                    self._size_counter = None
 
-        if len(self.chunks[-1]) >= self.chunk_length:
-            filename = self._dump(self.chunks[-1])
-            self.chunks[-1] = filename
-            self.chunks.append([])
+            if len(self.chunks[-1]) >= self.chunk_length:
+                filename = self._dump(self.chunks[-1])
+                self.chunks[-1] = filename
+                self.chunks.append([])
 
     def extend(self, value):
         for _ in value:
@@ -130,6 +135,17 @@ class BigArray(list):
 
         return ValueError, "%s is not in list" % value
 
+    def close(self):
+        while self.filenames:
+            filename = self.filenames.pop()
+            try:
+                self._os_remove(filename)
+            except OSError:
+                pass
+
+    def __del__(self):
+        self.close()
+
     def _dump(self, chunk):
         try:
             handle, filename = tempfile.mkstemp(prefix=MKSTEMP_PREFIX.BIG_ARRAY)
@@ -168,8 +184,12 @@ class BigArray(list):
         self.chunks, self.filenames = state
 
     def __getitem__(self, y):
+        length = len(self)
+        if length == 0:
+            raise IndexError("BigArray index out of range")
+
         while y < 0:
-            y += len(self)
+            y += length
 
         index = y // self.chunk_length
         offset = y % self.chunk_length
@@ -198,7 +218,10 @@ class BigArray(list):
 
     def __iter__(self):
         for i in xrange(len(self)):
-            yield self[i]
+            try:
+                yield self[i]
+            except IndexError:
+                break
 
     def __len__(self):
         return len(self.chunks[-1]) if len(self.chunks) == 1 else (len(self.chunks) - 1) * self.chunk_length + len(self.chunks[-1])
