@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
@@ -51,6 +51,6 @@ def parseSitemap(url, retVal=None):
         abortedFlag = True
         warnMsg = "user aborted during sitemap parsing. sqlmap "
         warnMsg += "will use partial list"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
     return retVal
